/**
 * ColumnSortPrefs
 * 
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.components.sft;

/**
 * Column sort preferences. This class holds column index and sort mode -
 * {@link SortMode#ASCENDING} or {@link SortMode#DESCENDING}
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public final class ColumnSortPrefs {

    /**
     * Column number
     */
    private final int columnIndex;

    /**
     * Sort mode
     */
    private final SortMode sortMode;


    /**
     * Constructs column sort preferences.
     *
     * @param columnIndex column index
     */
    public ColumnSortPrefs(int columnIndex, SortMode sortMode) {
        this.columnIndex = columnIndex;
        this.sortMode = sortMode;
    }


    /**
     * Returns column index
     *
     * @return column index
     */
    public int getColumnIndex() {
        return columnIndex;
    }


    /**
     * Returns sort mode. See {@link SortMode} class.
     *
     * @return sort mode
     */
    public SortMode getSortMode() {
        return sortMode;
    }

}
