/**
 * GenderComparator
 *
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.datatypes;

import java.util.Comparator;

/**
 * This class represents comparator for {@link Gender} type. <br>
 * The rule is: <code>male < female</code>
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
final public class GenderComparator implements Comparator<Gender> {

    /**
     * Gender comparator instance
     */
    public static final Comparator<Gender> INSTANCE = new GenderComparator();


    /**
     * Private constructor to avoid manual creation instead of {@link #INSTANCE}
     * usage.
     */
    private GenderComparator() {
    }


    /**
     * Compares two genders passed
     *
     * @param gender1 gender one to compare
     * @param gender2 gender two to compare
     *
     * @return comparison result. See class description.
     */
    public int compare(Gender gender1, Gender gender2) {
        if (gender1.equals(gender2)) {
            return 0;
        }
        return (gender1.equals(Gender.male)) ? -1 : 1;
    }

}
