/**
 * PhoneNumber
 *
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.datatypes;

/**
 * This class represents phone number
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public final class PhoneNumber {

    /**
     * Country code
     */
    private int countryCode;

    /**
     * Area code
     */
    private int areaCode;

    /**
     * Number
     */
    private int number;

    /**
     * Humanreadable number presentation in form
     * <code>+&lt;countryCode&gt;(&lt;areaCode&gt;)&lt;Number&gt;</code>
     */
    private String presentation;


    /**
     * Constructs phone number object
     *
     * @param countryCode country code
     * @param areaCode    area code
     * @param number      number
     */
    public PhoneNumber(int countryCode, int areaCode, int number) {
        this.countryCode = countryCode;
        this.areaCode = areaCode;
        this.number = number;
        StringBuffer sb = new StringBuffer();
        sb.append("+");
        sb.append(countryCode);
        sb.append(" (");
        String code = "00" + areaCode;
        sb.append(code.substring(code.length() - 3));
        sb.append(") ");
        sb.append(number);
        presentation = sb.toString();
    }


    /**
     * Returns area code
     *
     * @return area code
     */
    public int getAreaCode() {
        return areaCode;
    }


    /**
     * Returns number
     *
     * @return number
     */
    public int getNumber() {
        return number;
    }


    /**
     * Returns country code
     *
     * @return country code
     */
    public int getCountryCode() {
        return countryCode;
    }


    /**
     * Returns humanreadable phone number presentation
     *
     * @return humanreadable presentation
     */
    public String getPresentation() {
        return presentation;
    }

}
