/**
 * PhoneNumberComparators
 *
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.datatypes;

import java.util.Comparator;

/**
 * Phone number comparators collection. Currently have only one comparator
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public final class PhoneNumberComparators {

    /**
     * Private constructor to prevent instantiation
     */
    private PhoneNumberComparators() {
    }


    /**
     * Comparator instance
     */
    public static final Comparator<PhoneNumber> INSTANCE = new PhoneNumberComparator();

    /**
     * Comparator class. Compares {@link PhoneNumber}s
     */
    private static final class PhoneNumberComparator implements Comparator<PhoneNumber> {

        /**
         * Compares phone numbers. Comparison is numeric. First, area codes are compared.
         * If they are not equal - result is returned. Otherwise - numbers are compared.
         *
         * @param phoneNumber1 first number to compare
         * @param phoneNumber2 second number to compare
         *
         * @return comparison result: <code>-1</code>, <code>0</code> or <code>1</code>
         *         if phoneNumber1 is less then, equals to or greated then phoneNumber2 respectively.
         */
        public int compare(PhoneNumber phoneNumber1, PhoneNumber phoneNumber2) {
            if (phoneNumber1.getAreaCode() != phoneNumber2.getAreaCode()) {
                return (phoneNumber1.getAreaCode() < phoneNumber2.getAreaCode()) ? -1 : 1;
            } else {
                if (phoneNumber1.getNumber() != phoneNumber2.getNumber()) {
                    return (phoneNumber1.getNumber() < phoneNumber2.getNumber()) ? -1 : 1;
                }
            }
            return 0;
        }

    }

}
