/**
 * CellularPhoneFilter
 * 
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.filters;

import ru.skipy.filtering.Filter;
import ru.skipy.ui.components.sft.TableRow;
import ru.skipy.ui.test.sft.data.DataHolder;
import ru.skipy.ui.test.sft.datatypes.PhoneNumber;

/**
 * CellularPhoneFilter
 *
 * This filter accepts only table rows wich phone is a cellular one
 * (i.e., have area code &gt; 900)
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public class CellularPhoneFilter implements Filter<TableRow> {

    /**
     * Checks if row should be accepted
     *
     * @param tableRow row to check
     *
     * @return <code>true</code>, if 'phone' column of the row contain {@link PhoneNumber} with
     *         area code &gt; 900; <code>false</code> otherwise
     */
    public boolean accept(TableRow tableRow) {
        return tableRow.getCastedObjectAt(DataHolder.PHONE_IDX, PhoneNumber.class).getAreaCode() > 900;
    }


    /**
     * Returns filter name
     *
     * @return filter name
     */
    public String getName() {
        return "Cellular phones only";
    }


    /**
     * Returns filter description
     *
     * @return filter description
     */
    public String getDescription() {
        return "accepts only cellular phones";
    }


    /**
     * Returns filter rule in humanreadable form
     *
     * @return filter rule
     */
    public String getHumanreadableRule() {
        return "areaCode > 900";  //To change body of implemented methods use File | Settings | File Templates.
    }


    /**
     * Retuans filter's string representation (the same as name)
     *
     * @return filter's string representation
     */
    public String toString() {
        return getName();
    }

}
